==> docx4j-openxml-objects-8.3.10-sources.jar: org/docx4j/wml/STPageBorderDisplay.java <==
/*
 *  Copyright 2007-2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.wml; 

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_PageBorderDisplay.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_PageBorderDisplay">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="allPages"/>
 *     &lt;enumeration value="firstPage"/>
 *     &lt;enumeration value="notFirstPage"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_PageBorderDisplay")
@XmlEnum
public enum STPageBorderDisplay {


    /**
     * Display Page Border on All
     * 						Pages
     * 
     */
    @XmlEnumValue("allPages")
    ALL_PAGES("allPages"),

    /**
     * Display Page Border on First
     * 						Page
     * 
     */
    @XmlEnumValue("firstPage")
    FIRST_PAGE("firstPage"),

    /**
     * Display Page Border on All Pages Except
     * 						First
     * 
     */
    @XmlEnumValue("notFirstPage")
    NOT_FIRST_PAGE("notFirstPage");
    private final String value;

    STPageBorderDisplay(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STPageBorderDisplay fromValue(String v) {
        for (STPageBorderDisplay c: STPageBorderDisplay.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> docx4j-openxml-objects-11.4.7-sources.jar: org/docx4j/wml/STPageBorderDisplay.java <==
/*
 *  Copyright 2007-2013, Plutext Pty Ltd.
 *   
 *  This file is part of docx4j.

    docx4j is licensed under the Apache License, Version 2.0 (the "License"); 
    you may not use this file except in compliance with the License. 

    You may obtain a copy of the License at 

        http://www.apache.org/licenses/LICENSE-2.0 

    Unless required by applicable law or agreed to in writing, software 
    distributed under the License is distributed on an "AS IS" BASIS, 
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
    See the License for the specific language governing permissions and 
    limitations under the License.

 */


package org.docx4j.wml; 

import jakarta.xml.bind.annotation.XmlEnum;
import jakarta.xml.bind.annotation.XmlEnumValue;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ST_PageBorderDisplay.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <p>
 * <pre>
 * &lt;simpleType name="ST_PageBorderDisplay">
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string">
 *     &lt;enumeration value="allPages"/>
 *     &lt;enumeration value="firstPage"/>
 *     &lt;enumeration value="notFirstPage"/>
 *   &lt;/restriction>
 * &lt;/simpleType>
 * </pre>
 * 
 */
@XmlType(name = "ST_PageBorderDisplay")
@XmlEnum
public enum STPageBorderDisplay {


    /**
     * Display Page Border on All
     * 						Pages
     * 
     */
    @XmlEnumValue("allPages")
    ALL_PAGES("allPages"),

    /**
     * Display Page Border on First
     * 						Page
     * 
     */
    @XmlEnumValue("firstPage")
    FIRST_PAGE("firstPage"),

    /**
     * Display Page Border on All Pages Except
     * 						First
     * 
     */
    @XmlEnumValue("notFirstPage")
    NOT_FIRST_PAGE("notFirstPage");
    private final String value;

    STPageBorderDisplay(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static STPageBorderDisplay fromValue(String v) {
        for (STPageBorderDisplay c: STPageBorderDisplay.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
